use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
API

APIs

ASN

AVS

AdWords

Address
Alders
Alders'
Andy
BR

Base
BillingAddress
Bothwell
CCToken
CN

CVV

Chargeback
Christopher
Client
Country
CreditCard
Cronin
CustomInputs
DD

Data
DateTime
Dave
Device
Disposition
Eilam
Eilam's
Email
Enum
Error
Example
Factors
Florian
Fowler
FraudService
FraudServices

GEONAMES

Generic
GeoIP

GeoLite

GeoNames

GitHub

Gmail

Greg
HTTP
HasCommonAttributes
HasLocales
HasRisk
Hex32
Hostname
Hunter
IANA

IIN

IP

IP's

IPAddress
IPv

ISP

Inc
Insights
Issuer
Jack
Knop

Location
MAXMIND
MAXMIND's
Mark
MasterCard

Mateu
MaxMind
MaxMind

MaxMind's
MaxMind's

MinFraud
Model
Navarro
OC

Olaf
Omni

Oschwald
Oschwald

Oschwald's
Oxfordshire

Patrick
PayPal
RFC3339
Ragwitz
Record
Role
Rolsky
Rolsky

Rolsky's
Ruben
Rx
SSL

Score
ScoreIPAddress
ShippingAddress
Storey
Subscores
Type
Types
URI

VERSIONING

VPN

Validator
Warning
WebService
WebURI
William
YYY

YYYY

YYYZZZ

Yahoo

ajack
chargeback

christopher
contentDeliveryNetwork

cpanm

de

dialup

downloadable

drolsky
en

ergument

es

fr

geoname_id

goschwald
hostname

iPhones

ip

ja

lib
libmaxminddb

lookup

mark
maxmind

mhunter
minFraud

oalders
omni

params

pcronin
pt

rafl
rnavarro
routable

ru

searchEngineSpider

subscores

ua

unpopulated

versioning

wstorey
zh

